@@ -170,7 +170,7 @@ fitmoplot.tidal <- function(dat_in, month = c(1:12), tau = NULL, predicted = TRU
   # formatting for quantile legend labels
   quants <- gsub('^fit', '', names(to_plo)[tau_fits])
   quants <- lapply(as.list(quants), 
-    function(x) bquote(italic('\u03c4') ~ .(x))
+    function(x) bquote(italic(tau) ~ .(x))
   )
   
   # months labels as text
@@ -402,4 +402,4 @@ fitmoplot.tidalmean <- function(dat_in, month = c(1:12), predicted = TRUE, logsp
   
   return(p)
   
-}
\ No newline at end of file
+}
